@@ -147,4 +147,16 @@ Catmandu::Fix::marc_map - copy marc values of one field to a new field
     # Copy all 100 subfields except the digits to the 'author' field
     marc_map('100^0123456789','author')
 
+    # Map all the 500 - 599 fields to my.notes
+    marc_map('5**','my.motes')
+
+=head1 DESCRIPTION
+
+Read our Wiki pages at L<https://github.com/LibreCat/Catmandu/wiki/Fixes> for a complete
+overview of the Fix language.
+
+=head1 SEE ALSO
+
+L<Catmandu::Fix>
+
 =cut
